Index: src/x87/codegen-x87.cc |
diff --git a/src/x87/codegen-x87.cc b/src/x87/codegen-x87.cc |
index f6b8fc4f2ab37d7c44df83b78e891966740f96fd..56d273cf0abcd18dec3bc9a1733b735397c24f4c 100644 |
--- a/src/x87/codegen-x87.cc |
+++ b/src/x87/codegen-x87.cc |
@@ -531,7 +531,7 @@ void StringCharLoadGenerator::Generate(MacroAssembler* masm, |
__ j(zero, &seq_string, Label::kNear); |
// Handle external strings. |
- Label ascii_external, done; |
+ Label one_byte_external, done; |
if (FLAG_debug_code) { |
// Assert that we do not have a cons or slice (indirect strings) here. |
// Sequential strings have already been ruled out. |
@@ -546,22 +546,22 @@ void StringCharLoadGenerator::Generate(MacroAssembler* masm, |
STATIC_ASSERT(kTwoByteStringTag == 0); |
__ test_b(result, kStringEncodingMask); |
__ mov(result, FieldOperand(string, ExternalString::kResourceDataOffset)); |
- __ j(not_equal, &ascii_external, Label::kNear); |
+ __ j(not_equal, &one_byte_external, Label::kNear); |
// Two-byte string. |
__ movzx_w(result, Operand(result, index, times_2, 0)); |
__ jmp(&done, Label::kNear); |
- __ bind(&ascii_external); |
- // Ascii string. |
+ __ bind(&one_byte_external); |
+ // One-byte string. |
__ movzx_b(result, Operand(result, index, times_1, 0)); |
__ jmp(&done, Label::kNear); |
- // Dispatch on the encoding: ASCII or two-byte. |
- Label ascii; |
+ // Dispatch on the encoding: one-byte or two-byte. |
+ Label one_byte; |
__ bind(&seq_string); |
STATIC_ASSERT((kStringEncodingMask & kOneByteStringTag) != 0); |
STATIC_ASSERT((kStringEncodingMask & kTwoByteStringTag) == 0); |
__ test(result, Immediate(kStringEncodingMask)); |
- __ j(not_zero, &ascii, Label::kNear); |
+ __ j(not_zero, &one_byte, Label::kNear); |
// Two-byte string. |
// Load the two-byte character code into the result register. |
@@ -571,9 +571,9 @@ void StringCharLoadGenerator::Generate(MacroAssembler* masm, |
SeqTwoByteString::kHeaderSize)); |
__ jmp(&done, Label::kNear); |
- // Ascii string. |
+ // One-byte string. |
// Load the byte into the result register. |
- __ bind(&ascii); |
+ __ bind(&one_byte); |
__ movzx_b(result, FieldOperand(string, |
index, |
times_1, |